Class CreateAdapterVersionRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateAdapterVersionRequest.Builder,CreateAdapterVersionRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringA string containing a unique ID for the adapter that will receive a new version.builder()final StringIdempotent token is used to recognize the request.Specifies a dataset used to train a new adapter version.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanhasTags()For responses, this returns true if the service returned a value for the Tags property.final StringkmsKeyId()The identifier for your AWS Key Management Service key (AWS KMS key).final OutputConfigReturns the value of the OutputConfig property for this object.static Class<? extends CreateAdapterVersionRequest.Builder>tags()A set of tags (key-value pairs) that you want to attach to the adapter version.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
adapterId
A string containing a unique ID for the adapter that will receive a new version.
- Returns:
- A string containing a unique ID for the adapter that will receive a new version.
-
clientRequestToken
Idempotent token is used to recognize the request. If the same token is used with multiple CreateAdapterVersion requests, the same session is returned. This token is employed to avoid unintentionally creating the same session multiple times.
- Returns:
- Idempotent token is used to recognize the request. If the same token is used with multiple CreateAdapterVersion requests, the same session is returned. This token is employed to avoid unintentionally creating the same session multiple times.
-
datasetConfig
Specifies a dataset used to train a new adapter version. Takes a ManifestS3Object as the value.
- Returns:
- Specifies a dataset used to train a new adapter version. Takes a ManifestS3Object as the value.
-
kmsKeyId
The identifier for your AWS Key Management Service key (AWS KMS key). Used to encrypt your documents.
- Returns:
- The identifier for your AWS Key Management Service key (AWS KMS key). Used to encrypt your documents.
-
outputConfig
Returns the value of the OutputConfig property for this object.- Returns:
- The value of the OutputConfig property for this object.
-
hasTags
public final boolean hasTags()For responses, this returns true if the service returned a value for the Tags property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
tags
A set of tags (key-value pairs) that you want to attach to the adapter version.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasTags()method.- Returns:
- A set of tags (key-value pairs) that you want to attach to the adapter version.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateAdapterVersionRequest.Builder,CreateAdapterVersionRequest> - Specified by:
toBuilderin classTextractRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-